From david-b@pacbell.net Mon Apr 11 18:35:02 2005
From: David Brownell <david-b@pacbell.net>
Subject: USB: turn a user mode driver error into a hard error
Date: Mon, 11 Apr 2005 18:34:17 -0700
To: greg@kroah.com
Content-Length: 1750
Lines: 45


From: David Brownell <david-b@pacbell.net>

This patch turns a user mode driver error into a hard error, and updates
the relevant diagnostic slightly to help troubleshooting.  gphoto was
known to have this problem, hopefully it is now fixed (they have had
plenty of warning...)

This had been left as a soft error to give various user mode drivers a
change to be properly fixed, with the statement that starting in about
2.6.10 it would be changed.  It had been mostly safe as a soft error ... 
but that can not be guaranteed.  Now that a year has passed, it's time to
really insist that the user mode drivers finally fix their relevant bugs.

Signed-off-by: David Brownell <dbrownell@users.sourceforge.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

Index: gregkh-2.6/drivers/usb/core/devio.c
===================================================================
--- gregkh-2.6.orig/drivers/usb/core/devio.c	2005-04-12 00:41:49.000000000 -0700
+++ gregkh-2.6/drivers/usb/core/devio.c	2005-04-12 00:59:32.000000000 -0700
@@ -784,16 +784,16 @@
  		for (i = 0; i < actconfig->desc.bNumInterfaces; ++i) {
  			if (usb_interface_claimed(actconfig->interface[i])) {
 				dev_warn (&ps->dev->dev,
-					"usbfs: interface %d claimed "
+					"usbfs: interface %d claimed by %s "
 					"while '%s' sets config #%d\n",
 					actconfig->interface[i]
 						->cur_altsetting
 						->desc.bInterfaceNumber,
+					actconfig->interface[i]
+						->dev.driver->name,
 					current->comm, u);
-#if 0	/* FIXME:  enable in 2.6.10 or so */
  				status = -EBUSY;
 				break;
-#endif
 			}
  		}
  	}
